# Table of Contents

* [formatters.json\_formatter](#formatters.json_formatter)
  * [JsonFormatter](#formatters.json_formatter.JsonFormatter)
    * [serialise\_violation](#formatters.json_formatter.JsonFormatter.serialise_violation)

<a name="formatters.json_formatter"></a>
# formatters.json\_formatter

<a name="formatters.json_formatter.JsonFormatter"></a>
## JsonFormatter Objects

```python
class JsonFormatter(Formatter)
```

<a name="formatters.json_formatter.JsonFormatter.serialise_violation"></a>
#### serialise\_violation

```python
 | @staticmethod
 | serialise_violation(violation: BaseViolation)
```

Gets a meaningful string containing information about a violation

**Arguments**:

- `violation` - BaseViolation information
  
- `Returns` - a meaningful string containing information about a violation

